<?php
/**
 * Copyright © 2016 Filoblu S.r.l. All rights reserved.
 */

namespace FiloBlu\Esb\Block\Adminhtml\System\Config;

/**
 * Renderer for Gift Wrap associated products Configuration
 */

class Gwproducts extends \Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray
{
    
    /**
     * @var \Magento\GiftWrapping\Model\WrappingFactory
     */
    protected $wrappingFactory;

    /**
     * @var \Magento\GiftWrapping\Model\ResourceModel\Wrapping\CollectionFactory
     */
    protected $wrappingCollectionFactory;
    
    /**
     * @var Wrappings
     */
    protected $wrappingsRenderer = null;


    /**
     * Constructor
     *
     * @param \Magento\GiftWrapping\Model\ResourceModel\Wrapping\CollectionFactory $wrappingCollectionFactory
     * @param \Magento\GiftWrapping\Model\WrappingFactory $wrappingFactory
     * @param \Magento\Backend\Block\Template\Context $context
     */
    public function __construct(        
        \Magento\GiftWrapping\Model\WrappingFactory $wrappingFactory,
        \Magento\GiftWrapping\Model\ResourceModel\Wrapping\CollectionFactory $wrappingCollectionFactory,
        \Magento\Backend\Block\Template\Context $context, 
        array $data = []
    ) {
        $this->wrappingFactory = $wrappingFactory;
        $this->wrappingCollectionFactory = $wrappingCollectionFactory;
        parent::__construct($context, $data);
    }
    
    
    protected function _prepareToRender()
    {
        
        $wrappingCollectionItems = $this->wrappingCollectionFactory->create()->addStoreAttributesToResult()->getItems();  
        $wrappings = array();
        foreach($wrappingCollectionItems as $wrapping):
            $wrappings[] = array('value' => $wrapping['wrapping_id'], 'label' => __($wrapping['wrapping_id'] . ' - ' . $wrapping['design']));
        endforeach;
        
        array_unshift($wrappings,  array('value' => '*', 'label' => __('-- Any --')));  

        $gwprodBlock=$this->getLayout()->createBlock('Magento\Framework\View\Element\Html\Select')
                        ->setId($this->_getCellInputElementId('<%- _id %>','wrapping_id'))
                        ->setName($this->_getCellInputElementName('wrapping_id'))
                        ->setClass('select')
                        ->setOptions($wrappings);

        $this->addColumn('wrapping_id', array(
            'label' => __('Gift Wrap'),
            'renderer' => $gwprodBlock
        ));
        
        $this->addColumn('product_sku', array(
            'label' => __('Product SKU')
        ));

        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add new mapping');
    }
 
   
}
